<?php

namespace Drupal\symfony_mailer_queue_test\Plugin\EmailAdjuster;

use Drupal\Core\Language\LanguageInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\symfony_mailer\EmailInterface;
use Drupal\symfony_mailer\Plugin\EmailAdjuster\SubjectEmailAdjuster;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines the subject header email adjuster with mocked translation.
 *
 * @EmailAdjuster(
 *   id = "email_subject_translation",
 *   label = @Translation("Subject Translation"),
 *   description = @Translation("Sets the email subject with translation."),
 * )
 */
class SubjectTranslationEmailAdjuster extends SubjectEmailAdjuster implements ContainerFactoryPluginInterface {

  /**
   * The language manager.
   */
  protected LanguageManagerInterface $languageManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, ...$defaults): static {
    $instance = new static(...$defaults);
    $instance->languageManager = $container->get('language_manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function build(EmailInterface $email): void {
    parent::build($email);
    $current_langcode = $this->languageManager
      ->getCurrentLanguage(LanguageInterface::TYPE_INTERFACE)
      ->getId();
    $email->setSubject($this->t('This email might change everything', [], ['langcode' => $current_langcode]), TRUE);
  }

}
