<?php

namespace Drupal\Tests\symfony_mailer_queue\Traits;

use Drupal\locale\SourceString;

/**
 * Provides methods to add translations in tests.
 */
trait TranslationTestTrait {

  /**
   * Adds a translation for given target language.
   *
   * @param string $source_string
   *   The source string.
   * @param string $translated_string
   *   The translated string.
   * @param string $target_langcode
   *   The target langcode.
   */
  public function addTranslation(string $source_string, string $translated_string, string $target_langcode): void {

    /** @var \Drupal\locale\StringStorageInterface $storage */
    $storage = $this->container->get('locale.storage');

    // Find existing or create source string.
    $source = $storage->findString(['source' => $source_string]);
    if ($source === NULL) {
      $source = new SourceString();
      $source->setString($source_string);
      $source->setStorage($storage);
      $source->save();
    }

    // Create translation. If one already exists, it will be replaced.
    $target = $storage->createTranslation([
      'lid' => $source->lid,
      'language' => $target_langcode,
      'translation' => $translated_string,
    ]);
    $target->save();
  }

}
